pub struct ServiceHandler<Args, S>where
Args: FromRequest + 'static,
S: AsyncService<Input = Args> + 'static,
S::Output: Responder + 'static,
S::Error: ResponseError + 'static,{ /* private fields */ }Expand description
The highest level abstraction provided by this library. It is used to encapsulate underlying sod::Service
impls with an actix_web Handler that can be natively wired into an Actix actix_web::App.
Input tuples of FromRequest and outputs of Responder the responder trait make this directly compatible
with the native Actix request and response types.
See the this module’s documentation for details and examples.
Implementations
Sourceimpl<Args, S> ServiceHandler<Args, S>where
Args: FromRequest + 'static,
S: AsyncService<Input = Args> + 'static,
S::Output: Responder + 'static,
S::Error: ResponseError + 'static,
impl<Args, S> ServiceHandler<Args, S>where
Args: FromRequest + 'static,
S: AsyncService<Input = Args> + 'static,
S::Output: Responder + 'static,
S::Error: ResponseError + 'static,
Sourcepub fn new(service: S) -> Self
pub fn new(service: S) -> Self
Encapsulate the given sod::AsyncService or sod::Service to be used as an actix_web::Handler